
; NAME:
;       Local_Variance
;
; PURPOSE:
;       Compute Local variances of data array (spectrum, image) in a moving box,
;       of width specified by keyword BOX_WIDTH.
;
; CALLING:
;       Locvar = Local_Variance( data )
;
; INPUT:
;       data = array of numbers (vector, image, etc.)
;
; KEYWORDS:
;       BOX_WIDTH = the width in pixels of moving box
;                   in which to compute local variances, default=3.
;
;       MEAN_MEDIAN=
;       /USE_MEDIAN
;
; OUTPUTS:
;       Function returns the corresponding array of local variances.
;
; PROCEDURE:
;       Call the IDL smooth function twice.
; HISTORY:
;       Written, Frank Varosi NASA/GSFC 1992.
;-

function Local_Variance, data, BOX_WIDTH=boxwid, MEAN_MEDIAN=mm, MEDIAN=umed

        sz = size( data )
        if sz(0) LE 0 then begin
                print,"syntax:  Locvar = Local_Variance( data, BOX_WIDTH= )"
                print," data must be an array"
                return,0
           endif

        if N_elements( boxwid ) NE 1 then boxwid=3
        boxwid = ( 2 * (fix( boxwid )/2) + 1 ) > 3
        bw2 = boxwid^sz(0)
        fact = float( bw2 )/(bw2-1)

        if keyword_set( use_median ) then mm = median( data, boxwid ) $
                                        else mm = smooth( data, boxwid )

return, smooth( (data - mm)^2, boxwid ) * fact
end
